/**
 * Copyright 2014 Red Hat, Inc.
 * 
 * Red Hat licenses this file to you under the Apache License, version
 * 2.0 (the "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.  See the License for the specific language governing
 * permissions and limitations under the License.
 * 
 */
package org.fusesource.camel.component.sap;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sap.conn.jco.server.JCoServer;
import com.sap.conn.jco.server.JCoServerContextInfo;
import com.sap.conn.jco.server.JCoServerErrorListener;
import com.sap.conn.jco.server.JCoServerExceptionListener;

/**
 * Listener for Errors and Exceptions on server connections.
 * 
 * @author William Collins <punkhornsw@gmail.com>
 *
 */
public class ServerErrorAndExceptionListener implements JCoServerErrorListener, JCoServerExceptionListener {

	private static final Logger LOG = LoggerFactory.getLogger(SapSynchronousRfcServerComponent.class);

	@Override
	public void serverExceptionOccurred(JCoServer jcoServer, String connectionId,
			JCoServerContextInfo serverContext, Exception exception) {
		LOG.warn(">>> Exception occured on " + jcoServer.getProgramID() + " connection " + connectionId, exception);
	}

	@Override
	public void serverErrorOccurred(JCoServer jcoServer, String connectionId,
			JCoServerContextInfo serverContext, Error error) {
		LOG.warn(">>> Error occured on " + jcoServer.getProgramID() + " connection " + connectionId, error);
	}
	
}
